#[non_exhaustive]pub struct AutoAdjustData {
pub auto_adjust_type: AutoAdjustType,
pub historical_options: Option<HistoricalOptions>,
pub last_auto_adjust_time: Option<DateTime>,
}Expand description
The parameters that determine the budget amount for an auto-adjusting budget.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.auto_adjust_type: AutoAdjustTypeThe string that defines whether your budget auto-adjusts based on historical or forecasted data.
historical_options: Option<HistoricalOptions>The parameters that define or describe the historical data that your auto-adjusting budget is based on.
last_auto_adjust_time: Option<DateTime>The last time that your budget was auto-adjusted.
Implementations
Sourceimpl AutoAdjustData
impl AutoAdjustData
Sourcepub fn auto_adjust_type(&self) -> &AutoAdjustType
pub fn auto_adjust_type(&self) -> &AutoAdjustType
The string that defines whether your budget auto-adjusts based on historical or forecasted data.
Sourcepub fn historical_options(&self) -> Option<&HistoricalOptions>
pub fn historical_options(&self) -> Option<&HistoricalOptions>
The parameters that define or describe the historical data that your auto-adjusting budget is based on.
Sourcepub fn last_auto_adjust_time(&self) -> Option<&DateTime>
pub fn last_auto_adjust_time(&self) -> Option<&DateTime>
The last time that your budget was auto-adjusted.
Sourceimpl AutoAdjustData
impl AutoAdjustData
Sourcepub fn builder() -> AutoAdjustDataBuilder
pub fn builder() -> AutoAdjustDataBuilder
Creates a new builder-style object to manufacture AutoAdjustData.