#[non_exhaustive]pub struct BudgetNotificationsForAccount {
pub notifications: Option<Vec<Notification>>,
pub budget_name: Option<String>,
}Expand description
The budget name and associated notifications for an account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notifications: Option<Vec<Notification>>A list of notifications.
budget_name: Option<String>A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed.
Implementations
Sourceimpl BudgetNotificationsForAccount
impl BudgetNotificationsForAccount
Sourcepub fn notifications(&self) -> &[Notification]
pub fn notifications(&self) -> &[Notification]
A list of notifications.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .notifications.is_none().
Sourcepub fn budget_name(&self) -> Option<&str>
pub fn budget_name(&self) -> Option<&str>
A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed.
Sourceimpl BudgetNotificationsForAccount
impl BudgetNotificationsForAccount
Sourcepub fn builder() -> BudgetNotificationsForAccountBuilder
pub fn builder() -> BudgetNotificationsForAccountBuilder
Creates a new builder-style object to manufacture BudgetNotificationsForAccount.