#[non_exhaustive]pub struct ExpressionDimensionValues {
pub key: Dimension,
pub values: Vec<String>,
pub match_options: Option<Vec<MatchOption>>,
}Expand description
Contains the specifications for the filters to use for your request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: DimensionThe name of the dimension that you want to filter on.
values: Vec<String>The metadata values you can specify to filter upon, so that the results all match at least one of the specified values.
match_options: Option<Vec<MatchOption>>The match options that you can use to filter your results. You can specify only one of these values in the array.
Implementations
Sourceimpl ExpressionDimensionValues
impl ExpressionDimensionValues
Sourcepub fn values(&self) -> &[String]
pub fn values(&self) -> &[String]
The metadata values you can specify to filter upon, so that the results all match at least one of the specified values.
Sourcepub fn match_options(&self) -> &[MatchOption]
pub fn match_options(&self) -> &[MatchOption]
The match options that you can use to filter your results. You can specify only one of these values in the array.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .match_options.is_none().
Sourceimpl ExpressionDimensionValues
impl ExpressionDimensionValues
Sourcepub fn builder() -> ExpressionDimensionValuesBuilder
pub fn builder() -> ExpressionDimensionValuesBuilder
Creates a new builder-style object to manufacture ExpressionDimensionValues.