#[non_exhaustive]pub struct HealthStatus {
pub status: Option<HealthStatusValue>,
pub status_reason: Option<HealthStatusReason>,
pub last_updated_time: Option<DateTime>,
}Expand description
Provides information about the current operational state of a billing view resource, including its ability to access and update based on its associated billing view.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<HealthStatusValue>The current status of the billing view resource.
status_reason: Option<HealthStatusReason>The reason for the current status.
-
BILLING_VIEW_NO_ACCESS: The billing view resource does not grantbilling:GetBillingViewDatapermission to this account. -
BILLING_VIEW_UNHEALTHY: The billing view associated with the budget is unhealthy. -
FILTER_INVALID: The filter contains reference to an account you do not have access to. -
MULTI_YEAR_HISTORICAL_DATA_DISABLED: The budget is not being updated. Enable multi-year historical data in your Cost Management preferences.
last_updated_time: Option<DateTime>A generic time stamp. In Java, it's transformed to a Date object.
Implementations
Sourceimpl HealthStatus
impl HealthStatus
Sourcepub fn status(&self) -> Option<&HealthStatusValue>
pub fn status(&self) -> Option<&HealthStatusValue>
The current status of the billing view resource.
Sourcepub fn status_reason(&self) -> Option<&HealthStatusReason>
pub fn status_reason(&self) -> Option<&HealthStatusReason>
The reason for the current status.
-
BILLING_VIEW_NO_ACCESS: The billing view resource does not grantbilling:GetBillingViewDatapermission to this account. -
BILLING_VIEW_UNHEALTHY: The billing view associated with the budget is unhealthy. -
FILTER_INVALID: The filter contains reference to an account you do not have access to. -
MULTI_YEAR_HISTORICAL_DATA_DISABLED: The budget is not being updated. Enable multi-year historical data in your Cost Management preferences.
Sourcepub fn last_updated_time(&self) -> Option<&DateTime>
pub fn last_updated_time(&self) -> Option<&DateTime>
A generic time stamp. In Java, it's transformed to a Date object.
Sourceimpl HealthStatus
impl HealthStatus
Sourcepub fn builder() -> HealthStatusBuilder
pub fn builder() -> HealthStatusBuilder
Creates a new builder-style object to manufacture HealthStatus.